==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/LAYOUTMETA.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="LAYOUTFUNCNAME" type="{http://schemas.datastream.net/MP_fields}CODE40_Type"/>
 *         &lt;element name="LABELFUNCNAME" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *         &lt;element name="TOUSERGROUPS">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="USERGROUP" type="{http://schemas.datastream.net/MP_fields}CODE12_Type" maxOccurs="unbounded"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAGEFIELDS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAGEBLOCKS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAGELABELS"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "layoutfuncname",
    "labelfuncname",
    "tousergroups",
    "pagefields",
    "pageblocks",
    "pagelabels"
})
@XmlRootElement(name = "LAYOUTMETA")
public class LAYOUTMETA {

    @XmlElement(name = "LAYOUTFUNCNAME", required = true)
    protected String layoutfuncname;
    @XmlElement(name = "LABELFUNCNAME", required = true)
    protected String labelfuncname;
    @XmlElement(name = "TOUSERGROUPS", required = true)
    protected LAYOUTMETA.TOUSERGROUPS tousergroups;
    @XmlElement(name = "PAGEFIELDS", required = true)
    protected PAGEFIELDS pagefields;
    @XmlElement(name = "PAGEBLOCKS", required = true)
    protected PAGEBLOCKS pageblocks;
    @XmlElement(name = "PAGELABELS", required = true)
    protected PAGELABELS pagelabels;

    /**
     * Obtient la valeur de la propriété layoutfuncname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLAYOUTFUNCNAME() {
        return layoutfuncname;
    }

    /**
     * Définit la valeur de la propriété layoutfuncname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLAYOUTFUNCNAME(String value) {
        this.layoutfuncname = value;
    }

    /**
     * Obtient la valeur de la propriété labelfuncname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLABELFUNCNAME() {
        return labelfuncname;
    }

    /**
     * Définit la valeur de la propriété labelfuncname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLABELFUNCNAME(String value) {
        this.labelfuncname = value;
    }

    /**
     * Obtient la valeur de la propriété tousergroups.
     * 
     * @return
     *     possible object is
     *     {@link LAYOUTMETA.TOUSERGROUPS }
     *     
     */
    public LAYOUTMETA.TOUSERGROUPS getTOUSERGROUPS() {
        return tousergroups;
    }

    /**
     * Définit la valeur de la propriété tousergroups.
     * 
     * @param value
     *     allowed object is
     *     {@link LAYOUTMETA.TOUSERGROUPS }
     *     
     */
    public void setTOUSERGROUPS(LAYOUTMETA.TOUSERGROUPS value) {
        this.tousergroups = value;
    }

    /**
     * Obtient la valeur de la propriété pagefields.
     * 
     * @return
     *     possible object is
     *     {@link PAGEFIELDS }
     *     
     */
    public PAGEFIELDS getPAGEFIELDS() {
        return pagefields;
    }

    /**
     * Définit la valeur de la propriété pagefields.
     * 
     * @param value
     *     allowed object is
     *     {@link PAGEFIELDS }
     *     
     */
    public void setPAGEFIELDS(PAGEFIELDS value) {
        this.pagefields = value;
    }

    /**
     * Obtient la valeur de la propriété pageblocks.
     * 
     * @return
     *     possible object is
     *     {@link PAGEBLOCKS }
     *     
     */
    public PAGEBLOCKS getPAGEBLOCKS() {
        return pageblocks;
    }

    /**
     * Définit la valeur de la propriété pageblocks.
     * 
     * @param value
     *     allowed object is
     *     {@link PAGEBLOCKS }
     *     
     */
    public void setPAGEBLOCKS(PAGEBLOCKS value) {
        this.pageblocks = value;
    }

    /**
     * Obtient la valeur de la propriété pagelabels.
     * 
     * @return
     *     possible object is
     *     {@link PAGELABELS }
     *     
     */
    public PAGELABELS getPAGELABELS() {
        return pagelabels;
    }

    /**
     * Définit la valeur de la propriété pagelabels.
     * 
     * @param value
     *     allowed object is
     *     {@link PAGELABELS }
     *     
     */
    public void setPAGELABELS(PAGELABELS value) {
        this.pagelabels = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="USERGROUP" type="{http://schemas.datastream.net/MP_fields}CODE12_Type" maxOccurs="unbounded"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "usergroup"
    })
    public static class TOUSERGROUPS {

        @XmlElement(name = "USERGROUP", required = true)
        protected List<String> usergroup;

        /**
         * Gets the value of the usergroup property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the usergroup property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getUSERGROUP().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link String }
         * 
         * 
         */
        public List<String> getUSERGROUP() {
            if (usergroup == null) {
                usergroup = new ArrayList<String>();
            }
            return this.usergroup;
        }

    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/LAYOUTMETA.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="LAYOUTFUNCNAME" type="{http://schemas.datastream.net/MP_fields}CODE40_Type"/>
 *         &lt;element name="LABELFUNCNAME" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *         &lt;element name="TOUSERGROUPS">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="USERGROUP" type="{http://schemas.datastream.net/MP_fields}CODE12_Type" maxOccurs="unbounded"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAGEFIELDS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAGEBLOCKS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAGELABELS"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "layoutfuncname",
    "labelfuncname",
    "tousergroups",
    "pagefields",
    "pageblocks",
    "pagelabels"
})
@XmlRootElement(name = "LAYOUTMETA")
public class LAYOUTMETA {

    @XmlElement(name = "LAYOUTFUNCNAME", required = true)
    protected String layoutfuncname;
    @XmlElement(name = "LABELFUNCNAME", required = true)
    protected String labelfuncname;
    @XmlElement(name = "TOUSERGROUPS", required = true)
    protected LAYOUTMETA.TOUSERGROUPS tousergroups;
    @XmlElement(name = "PAGEFIELDS", required = true)
    protected PAGEFIELDS pagefields;
    @XmlElement(name = "PAGEBLOCKS", required = true)
    protected PAGEBLOCKS pageblocks;
    @XmlElement(name = "PAGELABELS", required = true)
    protected PAGELABELS pagelabels;

    /**
     * Gets the value of the layoutfuncname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLAYOUTFUNCNAME() {
        return layoutfuncname;
    }

    /**
     * Sets the value of the layoutfuncname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLAYOUTFUNCNAME(String value) {
        this.layoutfuncname = value;
    }

    /**
     * Gets the value of the labelfuncname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLABELFUNCNAME() {
        return labelfuncname;
    }

    /**
     * Sets the value of the labelfuncname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLABELFUNCNAME(String value) {
        this.labelfuncname = value;
    }

    /**
     * Gets the value of the tousergroups property.
     * 
     * @return
     *     possible object is
     *     {@link LAYOUTMETA.TOUSERGROUPS }
     *     
     */
    public LAYOUTMETA.TOUSERGROUPS getTOUSERGROUPS() {
        return tousergroups;
    }

    /**
     * Sets the value of the tousergroups property.
     * 
     * @param value
     *     allowed object is
     *     {@link LAYOUTMETA.TOUSERGROUPS }
     *     
     */
    public void setTOUSERGROUPS(LAYOUTMETA.TOUSERGROUPS value) {
        this.tousergroups = value;
    }

    /**
     * Gets the value of the pagefields property.
     * 
     * @return
     *     possible object is
     *     {@link PAGEFIELDS }
     *     
     */
    public PAGEFIELDS getPAGEFIELDS() {
        return pagefields;
    }

    /**
     * Sets the value of the pagefields property.
     * 
     * @param value
     *     allowed object is
     *     {@link PAGEFIELDS }
     *     
     */
    public void setPAGEFIELDS(PAGEFIELDS value) {
        this.pagefields = value;
    }

    /**
     * Gets the value of the pageblocks property.
     * 
     * @return
     *     possible object is
     *     {@link PAGEBLOCKS }
     *     
     */
    public PAGEBLOCKS getPAGEBLOCKS() {
        return pageblocks;
    }

    /**
     * Sets the value of the pageblocks property.
     * 
     * @param value
     *     allowed object is
     *     {@link PAGEBLOCKS }
     *     
     */
    public void setPAGEBLOCKS(PAGEBLOCKS value) {
        this.pageblocks = value;
    }

    /**
     * Gets the value of the pagelabels property.
     * 
     * @return
     *     possible object is
     *     {@link PAGELABELS }
     *     
     */
    public PAGELABELS getPAGELABELS() {
        return pagelabels;
    }

    /**
     * Sets the value of the pagelabels property.
     * 
     * @param value
     *     allowed object is
     *     {@link PAGELABELS }
     *     
     */
    public void setPAGELABELS(PAGELABELS value) {
        this.pagelabels = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="USERGROUP" type="{http://schemas.datastream.net/MP_fields}CODE12_Type" maxOccurs="unbounded"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "usergroup"
    })
    public static class TOUSERGROUPS {

        @XmlElement(name = "USERGROUP", required = true)
        protected List<String> usergroup;

        /**
         * Gets the value of the usergroup property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the usergroup property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getUSERGROUP().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link String }
         * 
         * 
         */
        public List<String> getUSERGROUP() {
            if (usergroup == null) {
                usergroup = new ArrayList<String>();
            }
            return this.usergroup;
        }

    }

}
